@@ -39,9 +39,16 @@ if sys.platform.startswith('win'):
 with open("README.rst") as readme:
     long_description = readme.read()
 
+# Populates __version__ without importing the package
+__version__ = None
+execfile('flexget/_version.py')
+if not __version__:
+    print 'Could not find __version__ from flexget/_version.py'
+    sys.exit(1)
+
 setup(
     name='FlexGet',
-    version='1.2',  # our tasks append the .1234 (current build number) to the version number
+    version=__version__,  # release task may edit this
     description='FlexGet is a program aimed to automate downloading or processing content (torrents, podcasts, etc.) '
                 'from different sources like RSS-feeds, html-pages, various sites and more.',
     long_description=long_description,
@@ -97,14 +104,48 @@ options(
 
 
 def set_init_version(ver):
-    """Replaces the version with ``ver`` in __init__.py"""
+    """Replaces the version with ``ver`` in _version.py"""
     import fileinput
-    for line in fileinput.FileInput('flexget/__init__.py', inplace=1):
+    for line in fileinput.FileInput('flexget/_version.py', inplace=1):
         if line.startswith('__version__ = '):
             line = "__version__ = '%s'\n" % ver
         print line,
 
 
+@task
+def version():
+    """Prints the version number of the source"""
+    print __version__
+
+
+@task
+@cmdopts([('dev', None, 'Bumps to new development version instead of release version.')])
+def increment_version(options):
+    """Increments either release or dev version by 1"""
+    print 'current version: %s' % __version__
+    ver_split = __version__.split('.')
+    dev = options.increment_version.get('dev')
+    if 'dev' in ver_split[-1]:
+        if dev:
+            # If this is already a development version, increment the dev count by 1
+            ver_split[-1] = 'dev%d' % (int(ver_split[-1].strip('dev') or 0) + 1)
+        else:
+            # Just strip off dev tag for next release version
+            ver_split = ver_split[:-1]
+    else:
+        # Increment the revision number by one
+        if len(ver_split) == 2:
+            # We don't have a revision number, assume 0
+            ver_split.append('1')
+        else:
+            ver_split[-1] = str(int(ver_split[-1]) + 1)
+        if dev:
+            ver_split.append('dev')
+    new_version = '.'.join(ver_split)
+    print 'new version: %s' % new_version
+    set_init_version(new_version)
+
+
 @task
 @cmdopts([
     ('online', None, 'Run online tests')
@@ -157,17 +198,10 @@ def clean():
 @cmdopts([
     ('dist-dir=', 'd', 'directory to put final built distributions in'),
     ('revision=', 'r', 'minor revision number of this build')
-], share_with=['make_egg'])
+])
 def sdist(options):
     """Build tar.gz distribution package"""
-
-    if not options.sdist.get('revision'):
-        print 'Revision number required.'
-        sys.exit(1)
-    revision = options.sdist.pop('revision')
-
-    print 'Revision: %s' % revision
-
+    print 'sdist version: %s' % __version__
     # clean previous build
     print 'Cleaning build...'
     for p in ['build']:
@@ -184,67 +218,9 @@ def sdist(options):
     for pyc in path('tests/').files('*.pyc'):
         pyc.remove()
 
-    ver = '%s.%s' % (options['version'], revision)
-
-    print 'Building %s' % ver
-
-    # replace version number
-    set_init_version(ver)
-
-    # hack version number into setup( ... options='1.0' ...)
-    from paver import tasks
-    setup_section = tasks.environment.options.setdefault("setup", Bunch())
-    setup_section.update(version=ver)
-
     for t in ['minilib', 'generate_setup', 'setuptools.command.sdist']:
         call_task(t)
 
-    # restore version ...
-    set_init_version('{git}')
-    return ver
-
-
-@task
-@cmdopts([
-    ('dist-dir=', 'd', 'directory to put final built distributions in'),
-    ('revision=', 'r', 'minor revision number of this build')
-], share_with=['sdist'])
-def make_egg(options):
-    # naming this task to bdist_egg will make egg installation fail
-
-    if not options.make_egg.get('revision'):
-        print 'Revision number required.'
-        sys.exit(1)
-    revision = options.make_egg.revision
-    ver = '%s.%s' % (options['version'], revision)
-
-    # hack version number into setup( ... options='1.0-svn' ...)
-    from paver import tasks
-    setup_section = tasks.environment.options.setdefault("setup", Bunch())
-    setup_section.update(version=ver)
-
-    # replace version number
-    set_init_version(ver)
-
-    print 'Making egg release'
-    import shutil
-    shutil.copytree('FlexGet.egg-info', 'FlexGet.egg-info-backup')
-
-    options.setdefault('bdist_egg', Bunch())['dist_dir'] = options.make_egg.get('dist_dir')
-
-    for t in ["minilib", "generate_setup", "setuptools.command.bdist_egg"]:
-        call_task(t)
-
-    # restore version ...
-    set_init_version('{git}')
-
-    # restore egg info from backup
-    print 'Removing FlexGet.egg-info ...'
-    shutil.rmtree('FlexGet.egg-info')
-    print 'Restoring FlexGet.egg-info'
-    shutil.move('FlexGet.egg-info-backup', 'FlexGet.egg-info')
-    return ver
-
 
 @task
 def coverage():
@@ -284,45 +260,18 @@ def docs():
 
 
 @task
-@might_call('test', 'sdist', 'make_egg')
-@cmdopts([
-    ('no-tests', None, 'skips unit tests'),
-    ('type=', None, 'type of release (src | egg)'),
-    ('ver-file=', None, 'java properties file to create with version number FG_VERSION')
-])
+@might_call('test', 'sdist')
+@cmdopts([('no-tests', None, 'skips unit tests')])
 def release(options):
-    """Make a FlexGet release. Same as bdist_egg but adds version information."""
-
-    if options.release.get('type') not in ['src', 'egg']:
-        print 'Invalid --type, must be src or egg'
-        sys.exit(1)
-
-    print 'Cleaning build...'
-    for p in ['build']:
-        pth = path(p)
-        if pth.isdir():
-            pth.rmtree()
-        elif pth.isfile():
-            pth.remove()
-        else:
-            print 'Unable to remove %s' % pth
-
-    # run unit tests
+    """Run tests then make an sdist if successful."""
     if not options.release.get('no_tests'):
         if not test():
             print 'Unit tests did not pass'
             sys.exit(1)
 
-    if options.release.get('type') == 'egg':
-        print 'Making egg release'
-        ver = make_egg()
-    else:
-        print 'Making src release'
-        ver = sdist()
+    print 'Making src release'
+    sdist()
 
-    if getattr(options.release, 'ver_file', False):
-        with open(options.release.ver_file, 'w') as ver_file:
-            ver_file.write('FG_VERSION=%s' % ver)
 
 @task
 def install_tools():
@@ -330,14 +279,14 @@ def install_tools():
 
     try:
         import pip
-    except:
+    except ImportError:
         print 'FATAL: Unable to import pip, please install it and run this again!'
         sys.exit(1)
 
     try:
         import sphinxcontrib
         print 'sphinxcontrib INSTALLED'
-    except:
+    except ImportError:
         pip.main(['install', 'sphinxcontrib-paverutils'])
 
     pip.main(['install', '-r', 'jenkins-requirements.txt'])
